@@ -14,6 +14,8 @@ import numpy as np
 import sys
 import os
 
+import pkg_resources
+
 def main():
     usage = """%prog SPECTRA DB [module options] [input and configuration options]
 
@@ -108,7 +110,7 @@ def main():
     if labels:
         labels = labels.split(",")
     Counts = options.counts
-    config_path = os.path.dirname(os.path.realpath(__file__))+"/config_files/"
+    # config_path = os.path.dirname(os.path.realpath(__file__))+"/config_files/"
 
     if not options.spec_dir:
         options.spec_dir = ""
@@ -136,7 +138,7 @@ def main():
                     countList.append([count for count in sample_counts])
             else:  # use InSpect
                 from runInspect_user_config import runInspect_config
-                insp_config = config_path+"config_Inspect_py.txt"  # configuration file for InSpect
+                insp_config = pkg_resources.resource_filename(__name__, os.path.join("config_files", "config_Inspect_py.txt")) # configuration file for InSpect
                 # Automatized configuration and execution of Inspect peptide identification for
                 # a list of spectrum files and a list of reference proteomes.
                 runInspect_config(spectra=spectra,
